"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var transform_fragment_document_1 = require("./transform-fragment-document");
var kinds_1 = require("graphql/language/kinds");
var transform_operation_1 = require("./transform-operation");
var debugging_1 = require("../debugging");
function transformDocument(schema, documentNode) {
    var result = {
        fragments: [],
        operations: [],
        hasFragments: false,
        hasOperations: false,
    };
    var definitions = (documentNode.definitions || []);
    debugging_1.debugLog("[transformDocument] transforming total of " + definitions.length + " definitions...");
    definitions.forEach(function (definitionNode) {
        if (definitionNode.kind === kinds_1.OPERATION_DEFINITION) {
            result.operations.push(transform_operation_1.transformOperation(schema, definitionNode));
        }
        else if (definitionNode.kind === kinds_1.FRAGMENT_DEFINITION) {
            result.fragments.push(transform_fragment_document_1.transformFragment(schema, definitionNode));
        }
        else {
            console.log("WARNING: It seems like you provided a GraphQL schema instead of GraphQL document: ");
            console.log(definitionNode);
        }
    });
    result.hasFragments = result.fragments.length > 0;
    result.hasOperations = result.operations.length > 0;
    return result;
}
exports.transformDocument = transformDocument;
//# sourceMappingURL=transform-document.js.map